@@ -16,6 +16,12 @@
 import re
 from threading import Timer
 
+SAMPLES_PER_SECOND = 48000
+NUM_CHANNELS = 1
+MAX_SILENCE_DURATION = 30*1000 #30 seconds
+BUFFER_DURATION = 10 # ms Must be 10ms or a multiple thereof
+WATCHDOG_RATE = 5 # ms
+
 class Watchdog(Exception):
     def __init__(self, timeout, handler=None):
         self.timeout = timeout
